diff --git a/wlauto/workloads/googleslides/__init__.py b/wlauto/workloads/googleslides/__init__.py
index ab9d2805..a825bd55 100755
--- a/wlauto/workloads/googleslides/__init__.py
+++ b/wlauto/workloads/googleslides/__init__.py
@@ -132,5 +132,6 @@ class GoogleSlides(AndroidUxPerfWorkload):
def teardown(self, context):
super(GoogleSlides, self).teardown(context)
# Remove the newly created file
- self.device.delete_file(self.device.path.join(self.device.working_directory, self.new_doc_name))
- self.device.broadcast_media_mounted(self.device.working_directory)
+ f = self.device.path.join(self.device.working_directory, self.new_doc_name)
+ self.device.delete_file(f)
+ self.device.broadcast_media_scan_file(f)
diff --git a/wlauto/workloads/googleslides/com.arm.wlauto.uiauto.googleslides.jar b/wlauto/workloads/googleslides/com.arm.wlauto.uiauto.googleslides.jar
deleted file mode 100644
index 277be6ee..00000000
Binary files a/wlauto/workloads/googleslides/com.arm.wlauto.uiauto.googleslides.jar and /dev/null differ
diff --git a/wlauto/workloads/googleslides/com.arm.wlauto.uiauto.googleslides.uiautoapk b/wlauto/workloads/googleslides/com.arm.wlauto.uiauto.googleslides.uiautoapk
new file mode 100644
index 00000000..cd7286c8
Binary files /dev/null and b/wlauto/workloads/googleslides/com.arm.wlauto.uiauto.googleslides.uiautoapk differ
diff --git a/wlauto/workloads/googleslides/uiauto/app/build.gradle b/wlauto/workloads/googleslides/uiauto/app/build.gradle
new file mode 100644
index 00000000..8ca358ad
--- /dev/null
+++ b/wlauto/workloads/googleslides/uiauto/app/build.gradle
@@ -0,0 +1,36 @@
+apply plugin: 'com.android.application'
+
+def packageName = "com.arm.wlauto.uiauto.googleslides"
+
+android {
+ compileSdkVersion 25
+ buildToolsVersion "25.0.3"
+ defaultConfig {
+ applicationId "${packageName}"
+ minSdkVersion 18
+ targetSdkVersion 25
+ testInstrumentationRunner "android.support.test.runner.AndroidJUnitRunner"
+ }
+ buildTypes {
+ applicationVariants.all { variant ->
+ variant.outputs.each { output ->
+ output.outputFile = file("$project.buildDir/apk/${packageName}.apk")
+ }
+ }
+ }
+}
+
+dependencies {
+ compile fileTree(dir: 'libs', include: ['*.jar'])
+ compile 'com.android.support.test:runner:0.5'
+ compile 'com.android.support.test:rules:0.5'
+ // Using older version of uitautomator as the latest version can't find canvas elements.
+ compile 'com.android.support.test.uiautomator:uiautomator-v18:2.1.1'
+ compile(name: 'uiauto', ext:'aar')
+}
+
+repositories {
+ flatDir {
+ dirs 'libs'
+ }
+}
diff --git a/wlauto/workloads/googleslides/uiauto/app/src/main/AndroidManifest.xml b/wlauto/workloads/googleslides/uiauto/app/src/main/AndroidManifest.xml
new file mode 100644
index 00000000..16dc1bdb
--- /dev/null
+++ b/wlauto/workloads/googleslides/uiauto/app/src/main/AndroidManifest.xml
@@ -0,0 +1,12 @@
+
+
+
+
+
+
+
diff --git a/wlauto/workloads/googleslides/uiauto/src/com/arm/wlauto/uiauto/UiAutomation.java b/wlauto/workloads/googleslides/uiauto/app/src/main/java/com/arm/wlauto/uiauto/googleslides/UiAutomation.java
similarity index 75%
rename from wlauto/workloads/googleslides/uiauto/src/com/arm/wlauto/uiauto/UiAutomation.java
rename to wlauto/workloads/googleslides/uiauto/app/src/main/java/com/arm/wlauto/uiauto/googleslides/UiAutomation.java
index 2e81263b..ae7ad017 100755
--- a/wlauto/workloads/googleslides/uiauto/src/com/arm/wlauto/uiauto/UiAutomation.java
+++ b/wlauto/workloads/googleslides/uiauto/app/src/main/java/com/arm/wlauto/uiauto/googleslides/UiAutomation.java
@@ -15,27 +15,27 @@
package com.arm.wlauto.uiauto.googleslides;
-import java.io.File;
-import java.util.LinkedHashMap;
-import java.util.Map;
-
import android.graphics.Rect;
import android.os.Bundle;
import android.os.SystemClock;
-
-// Import the uiautomator libraries
-import com.android.uiautomator.core.Configurator;
-import com.android.uiautomator.core.UiObject;
-import com.android.uiautomator.core.UiObjectNotFoundException;
-import com.android.uiautomator.core.UiScrollable;
-import com.android.uiautomator.core.UiSelector;
+import android.support.test.runner.AndroidJUnit4;
+import android.support.test.uiautomator.Configurator;
+import android.support.test.uiautomator.UiObject;
+import android.support.test.uiautomator.UiScrollable;
+import android.support.test.uiautomator.UiSelector;
import com.arm.wlauto.uiauto.UxPerfUiAutomation;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+
+import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_DESC;
import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_ID;
import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_TEXT;
-import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_DESC;
+// Import the uiautomator libraries
+
+@RunWith(AndroidJUnit4.class)
public class UiAutomation extends UxPerfUiAutomation {
public Bundle parameters;
@@ -46,9 +46,11 @@ public class UiAutomation extends UxPerfUiAutomation {
public static final int SLIDE_WAIT_TIME_MS = 200;
public static final int DEFAULT_SWIPE_STEPS = 10;
+ @Test
public void runUiAutomation() throws Exception {
+ initialize_instrumentation();
parameters = getParams();
- packageName = parameters.getString("package");
+ packageName = parameters.getString("package_name");
packageID = packageName + ":id/";
String newDocumentName = parameters.getString("new_doc_name");
@@ -80,28 +82,29 @@ public class UiAutomation extends UxPerfUiAutomation {
public void dismissWorkOfflineBanner() throws Exception {
UiObject banner =
- new UiObject(new UiSelector().textContains("Work offline"));
+ mDevice.findObject(new UiSelector().textContains("Work offline"));
if (banner.waitForExists(WAIT_TIMEOUT_1SEC)) {
clickUiObject(BY_TEXT, "Got it", "android.widget.Button");
}
}
public void dismissUpdateDialog() throws Exception {
- UiObject update =
- new UiObject(new UiSelector().textContains("App update recommended"));
- if (update.waitForExists(WAIT_TIMEOUT_1SEC)) {
- clickUiObject(BY_TEXT, "Dismiss");
+ UiObject update =
+ mDevice.findObject(new UiSelector().textContains("App update recommended"));
+ if (update.waitForExists(WAIT_TIMEOUT_1SEC)) {
+ clickUiObject(BY_TEXT, "Dismiss");
}
}
public void enterTextInSlide(String viewName, String textToEnter) throws Exception {
UiObject view =
- new UiObject(new UiSelector().resourceId(packageID + "main_canvas")
+ mDevice.findObject(new UiSelector().resourceId(packageID + "main_canvas")
.childSelector(new UiSelector()
.descriptionMatches(viewName)));
view.click();
- getUiDevice().pressEnter();
- view.setText(textToEnter);
+ mDevice.pressEnter();
+ view.legacySetText(textToEnter);
+
tapOpenArea();
// On some devices, keyboard pops up when entering text, and takes a noticeable
// amount of time (few milliseconds) to disappear after clicking Done.
@@ -116,7 +119,7 @@ public class UiAutomation extends UxPerfUiAutomation {
}
public void insertImage(String workingDirectoryName) throws Exception {
- UiObject insertButton = new UiObject(new UiSelector().descriptionContains("Insert"));
+ UiObject insertButton = mDevice.findObject(new UiSelector().descriptionContains("Insert"));
if (insertButton.exists()) {
insertButton.click();
} else {
@@ -126,13 +129,13 @@ public class UiAutomation extends UxPerfUiAutomation {
clickUiObject(BY_TEXT, "Image", true);
clickUiObject(BY_TEXT, "From photos");
- UiObject imagesFolder = new UiObject(new UiSelector().className("android.widget.TextView").textContains("Images"));
+ UiObject imagesFolder = mDevice.findObject(new UiSelector().className("android.widget.TextView").textContains("Images"));
if (!imagesFolder.waitForExists(WAIT_TIMEOUT_1SEC*10)) {
clickUiObject(BY_DESC, "Show roots");
}
imagesFolder.click();
- UiObject folderEntry = new UiObject(new UiSelector().textContains(workingDirectoryName));
+ UiObject folderEntry = mDevice.findObject(new UiSelector().textContains(workingDirectoryName));
UiScrollable list = new UiScrollable(new UiSelector().scrollable(true));
if (!folderEntry.exists() && list.waitForExists(WAIT_TIMEOUT_1SEC)) {
list.scrollIntoView(folderEntry);
@@ -148,7 +151,7 @@ public class UiAutomation extends UxPerfUiAutomation {
ActionLogger logger = new ActionLogger(testTag, parameters);
UiObject insertButton =
- new UiObject(new UiSelector().descriptionContains("Insert"));
+ mDevice.findObject(new UiSelector().descriptionContains("Insert"));
logger.start();
if (insertButton.exists()) {
insertButton.click();
@@ -166,7 +169,7 @@ public class UiAutomation extends UxPerfUiAutomation {
ActionLogger logger = new ActionLogger(testTag, parameters);
UiObject resizeHandle =
- new UiObject(new UiSelector().descriptionMatches(".*Bottom[- ]right resize.*"));
+ mDevice.findObject(new UiSelector().descriptionMatches(".*Bottom[- ]right resize.*"));
Rect bounds = resizeHandle.getVisibleBounds();
int newX = bounds.left - 40;
int newY = bounds.bottom - 40;
@@ -178,9 +181,9 @@ public class UiAutomation extends UxPerfUiAutomation {
logger = new ActionLogger(testTag, parameters);
UiObject shapeSelector =
- new UiObject(new UiSelector().resourceId(packageID + "main_canvas")
- .childSelector(new UiSelector()
- .descriptionContains(shapeName)));
+ mDevice.findObject(new UiSelector().resourceId(packageID + "main_canvas")
+ .childSelector(new UiSelector()
+ .descriptionContains(shapeName)));
logger.start();
shapeSelector.dragTo(newX, newY, 40);
logger.stop();
@@ -194,7 +197,7 @@ public class UiAutomation extends UxPerfUiAutomation {
clickUiObject(BY_TEXT, "Device storage", true);
clickUiObject(BY_DESC, "Navigate up");
UiScrollable list =
- new UiScrollable(new UiSelector().className("android.widget.ListView"));
+ new UiScrollable(new UiSelector().className("android.widget.ListView"));
list.scrollIntoView(new UiSelector().textMatches(workingDirectoryName));
clickUiObject(BY_TEXT, workingDirectoryName);
list.scrollIntoView(new UiSelector().textContains(docName));
@@ -211,42 +214,42 @@ public class UiAutomation extends UxPerfUiAutomation {
logger.start();
clickUiObject(BY_DESC, "New presentation");
clickUiObject(BY_TEXT, "New PowerPoint", true);
- logger.stop();
+ logger.stop();
dismissUpdateDialog();
}
- public void saveDocument(String docName) throws Exception {
- String testTag = "document_save";
- ActionLogger logger = new ActionLogger(testTag, parameters);
+ public void saveDocument(String docName) throws Exception {
+ String testTag = "document_save";
+ ActionLogger logger = new ActionLogger(testTag, parameters);
- UiObject saveActionButton =
- new UiObject(new UiSelector().text("save"));
- UiObject unsavedIndicator =
- new UiObject(new UiSelector().textContains("Unsaved changes"));
- logger.start();
- if (saveActionButton.waitForExists(WAIT_TIMEOUT_1SEC)) {
- saveActionButton.click();
- } else if (unsavedIndicator.waitForExists(WAIT_TIMEOUT_1SEC)) {
- unsavedIndicator.click();
- }
- clickUiObject(BY_TEXT, "Device");
- UiObject save = clickUiObject(BY_TEXT, "Save", "android.widget.Button");
- if (save.waitForExists(WAIT_TIMEOUT_1SEC)) {
- save.click();
- }
- logger.stop();
+ UiObject saveActionButton =
+ mDevice.findObject(new UiSelector().textMatches("save|SAVE"));
+ UiObject unsavedIndicator =
+ mDevice.findObject(new UiSelector().textContains("Unsaved changes"));
+ logger.start();
+ if (saveActionButton.waitForExists(WAIT_TIMEOUT_1SEC)) {
+ saveActionButton.click();
+ } else if (unsavedIndicator.waitForExists(WAIT_TIMEOUT_1SEC)) {
+ unsavedIndicator.click();
+ }
+ clickUiObject(BY_TEXT, "Device");
+ UiObject save = clickUiObject(BY_TEXT, "Save", "android.widget.Button");
+ if (save.waitForExists(WAIT_TIMEOUT_1SEC)) {
+ save.click();
+ }
+ logger.stop();
- // Overwrite if prompted
- // Should not happen under normal circumstances. But ensures test doesn't stop
- // if a previous iteration failed prematurely and was unable to delete the file.
- // Note that this file isn't removed during workload teardown as deleting it is
- // part of the UiAutomator test case.
- UiObject overwriteView =
- new UiObject(new UiSelector().textContains("already exists"));
- if (overwriteView.waitForExists(WAIT_TIMEOUT_1SEC)) {
- clickUiObject(BY_TEXT, "Overwrite");
- }
- }
+ // Overwrite if prompted
+ // Should not happen under normal circumstances. But ensures test doesn't stop
+ // if a previous iteration failed prematurely and was unable to delete the file.
+ // Note that this file isn't removed during workload teardown as deleting it is
+ // part of the UiAutomator test case.
+ UiObject overwriteView =
+ mDevice.findObject(new UiSelector().textContains("already exists"));
+ if (overwriteView.waitForExists(WAIT_TIMEOUT_1SEC)) {
+ clickUiObject(BY_TEXT, "Overwrite");
+ }
+ }
public void deleteDocument(String docName) throws Exception {
String testTag = "document_delete";
@@ -254,28 +257,28 @@ public class UiAutomation extends UxPerfUiAutomation {
String filenameRegex = String.format(".*((%s)|([Uu]ntitled presentation)).pptx.*", docName);
UiObject doc =
- new UiObject(new UiSelector().textMatches(filenameRegex));
+ mDevice.findObject(new UiSelector().textMatches(filenameRegex));
UiObject moreActions =
doc.getFromParent(new UiSelector().descriptionContains("More actions"));
-
+
logger.start();
moreActions.click();
UiObject deleteButton =
- new UiObject(new UiSelector().textMatches(".*([Dd]elete|[Rr]emove).*"));
+ mDevice.findObject(new UiSelector().textMatches(".*([Dd]elete|[Rr]emove).*"));
if (deleteButton.waitForExists(WAIT_TIMEOUT_1SEC)) {
deleteButton.click();
} else {
// Delete button not found, try to scroll the view
UiScrollable scrollable =
- new UiScrollable(new UiSelector().scrollable(true)
- .childSelector(new UiSelector()
- .textContains("Rename")));
+ new UiScrollable(new UiSelector().scrollable(true)
+ .childSelector(new UiSelector()
+ .textContains("Rename")));
if (scrollable.exists()) {
scrollable.scrollIntoView(deleteButton);
} else {
UiObject content =
- new UiObject(new UiSelector().resourceId(packageID + "content"));
+ mDevice.findObject(new UiSelector().resourceId(packageID + "content"));
int attemptsLeft = 10; // try a maximum of 10 swipe attempts
while (!deleteButton.exists() && attemptsLeft > 0) {
content.swipeUp(DEFAULT_SWIPE_STEPS);
@@ -286,8 +289,8 @@ public class UiAutomation extends UxPerfUiAutomation {
}
UiObject okButton =
- new UiObject(new UiSelector().textContains("OK")
- .className("android.widget.Button"));
+ mDevice.findObject(new UiSelector().textContains("OK")
+ .className("android.widget.Button"));
if (okButton.waitForExists(WAIT_TIMEOUT_1SEC)) {
okButton.clickAndWaitForNewWindow();
} else {
@@ -304,10 +307,11 @@ public class UiAutomation extends UxPerfUiAutomation {
String testTag = "enable_pptmode";
ActionLogger logger = new ActionLogger(testTag, parameters);
logger.start();
- clickUiObject(BY_DESC, "drawer");
+
+ clickUiObject(BY_DESC, "Open navigation drawer");
clickUiObject(BY_TEXT, "Settings", true);
clickUiObject(BY_TEXT, "Create PowerPoint");
- getUiDevice().pressBack();
+ mDevice.pressBack();
logger.stop();
}
@@ -342,11 +346,11 @@ public class UiAutomation extends UxPerfUiAutomation {
String shapeName = "Rounded rectangle";
insertShape(shapeName);
modifyShape(shapeName);
- getUiDevice().pressBack();
+ mDevice.pressBack();
sleep(1);
// Tidy up
- getUiDevice().pressBack();
+ mDevice.pressBack();
dismissWorkOfflineBanner(); // if it appears on the homescreen
// Note: Currently disabled because it fails on Samsung devices
@@ -361,7 +365,7 @@ public class UiAutomation extends UxPerfUiAutomation {
// selecting any shapes or text boxes inside the slides while swiping, which may
// cause the view to switch into edit mode and fail the test
UiObject slideCanvas =
- new UiObject(new UiSelector().resourceId(packageID + "main_canvas"));
+ mDevice.findObject(new UiSelector().resourceId(packageID + "main_canvas"));
Rect canvasBounds = slideCanvas.getVisibleBounds();
int leftEdge = canvasBounds.left + 10;
int rightEdge = canvasBounds.right - 10;
@@ -393,19 +397,19 @@ public class UiAutomation extends UxPerfUiAutomation {
logger.start();
clickUiObject(BY_DESC, "Start slideshow", true);
UiObject onDevice =
- new UiObject(new UiSelector().textContains("this device"));
+ mDevice.findObject(new UiSelector().textContains("this device"));
if (onDevice.waitForExists(WAIT_TIMEOUT_1SEC)) {
onDevice.clickAndWaitForNewWindow();
waitForProgress(WAIT_TIMEOUT_1SEC*30);
UiObject presentation =
- new UiObject(new UiSelector().descriptionContains("Presentation Viewer"));
+ mDevice.findObject(new UiSelector().descriptionContains("Presentation Viewer"));
presentation.waitForExists(WAIT_TIMEOUT_1SEC*30);
}
logger.stop();
sleep(1);
slideIndex = 0;
-
+
// scroll forward in slideshow mode
logger = new ActionLogger(testTag + "_playforward", parameters);
logger.start();
@@ -426,12 +430,12 @@ public class UiAutomation extends UxPerfUiAutomation {
logger.stop();
sleep(1);
- getUiDevice().pressBack();
- getUiDevice().pressBack();
+ mDevice.pressBack();
+ mDevice.pressBack();
}
protected boolean waitForProgress(int timeout) throws Exception {
- UiObject progress = new UiObject(new UiSelector().className("android.widget.ProgressBar"));
+ UiObject progress = mDevice.findObject(new UiSelector().className("android.widget.ProgressBar"));
if (progress.waitForExists(WAIT_TIMEOUT_1SEC)) {
return progress.waitUntilGone(timeout);
} else {
@@ -455,7 +459,7 @@ public class UiAutomation extends UxPerfUiAutomation {
public void windowApplication() throws Exception {
UiObject window =
- new UiObject(new UiSelector().resourceId("android:id/restore_window"));
+ mDevice.findObject(new UiSelector().resourceId("android:id/restore_window"));
if (window.waitForExists(WAIT_TIMEOUT_1SEC)){
window.click();
}
diff --git a/wlauto/workloads/googleslides/uiauto/build.gradle b/wlauto/workloads/googleslides/uiauto/build.gradle
new file mode 100644
index 00000000..b78a0b86
--- /dev/null
+++ b/wlauto/workloads/googleslides/uiauto/build.gradle
@@ -0,0 +1,23 @@
+// Top-level build file where you can add configuration options common to all sub-projects/modules.
+
+buildscript {
+ repositories {
+ jcenter()
+ }
+ dependencies {
+ classpath 'com.android.tools.build:gradle:2.3.1'
+
+ // NOTE: Do not place your application dependencies here; they belong
+ // in the individual module build.gradle files
+ }
+}
+
+allprojects {
+ repositories {
+ jcenter()
+ }
+}
+
+task clean(type: Delete) {
+ delete rootProject.buildDir
+}
diff --git a/wlauto/workloads/googleslides/uiauto/build.xml b/wlauto/workloads/googleslides/uiauto/build.xml
deleted file mode 100644
index 259eaa6e..00000000
--- a/wlauto/workloads/googleslides/uiauto/build.xml
+++ /dev/null
@@ -1,92 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/wlauto/workloads/googleslides/uiauto/gradle/wrapper/gradle-wrapper.jar b/wlauto/workloads/googleslides/uiauto/gradle/wrapper/gradle-wrapper.jar
new file mode 100644
index 00000000..13372aef
Binary files /dev/null and b/wlauto/workloads/googleslides/uiauto/gradle/wrapper/gradle-wrapper.jar differ
diff --git a/wlauto/workloads/googleslides/uiauto/gradle/wrapper/gradle-wrapper.properties b/wlauto/workloads/googleslides/uiauto/gradle/wrapper/gradle-wrapper.properties
new file mode 100644
index 00000000..760fcce7
--- /dev/null
+++ b/wlauto/workloads/googleslides/uiauto/gradle/wrapper/gradle-wrapper.properties
@@ -0,0 +1,6 @@
+#Wed May 03 15:42:44 BST 2017
+distributionBase=GRADLE_USER_HOME
+distributionPath=wrapper/dists
+zipStoreBase=GRADLE_USER_HOME
+zipStorePath=wrapper/dists
+distributionUrl=https\://services.gradle.org/distributions/gradle-3.3-all.zip
diff --git a/wlauto/workloads/googleslides/uiauto/gradlew b/wlauto/workloads/googleslides/uiauto/gradlew
new file mode 100755
index 00000000..9d82f789
--- /dev/null
+++ b/wlauto/workloads/googleslides/uiauto/gradlew
@@ -0,0 +1,160 @@
+#!/usr/bin/env bash
+
+##############################################################################
+##
+## Gradle start up script for UN*X
+##
+##############################################################################
+
+# Add default JVM options here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM options to this script.
+DEFAULT_JVM_OPTS=""
+
+APP_NAME="Gradle"
+APP_BASE_NAME=`basename "$0"`
+
+# Use the maximum available, or set MAX_FD != -1 to use that value.
+MAX_FD="maximum"
+
+warn ( ) {
+ echo "$*"
+}
+
+die ( ) {
+ echo
+ echo "$*"
+ echo
+ exit 1
+}
+
+# OS specific support (must be 'true' or 'false').
+cygwin=false
+msys=false
+darwin=false
+case "`uname`" in
+ CYGWIN* )
+ cygwin=true
+ ;;
+ Darwin* )
+ darwin=true
+ ;;
+ MINGW* )
+ msys=true
+ ;;
+esac
+
+# Attempt to set APP_HOME
+# Resolve links: $0 may be a link
+PRG="$0"
+# Need this for relative symlinks.
+while [ -h "$PRG" ] ; do
+ ls=`ls -ld "$PRG"`
+ link=`expr "$ls" : '.*-> \(.*\)$'`
+ if expr "$link" : '/.*' > /dev/null; then
+ PRG="$link"
+ else
+ PRG=`dirname "$PRG"`"/$link"
+ fi
+done
+SAVED="`pwd`"
+cd "`dirname \"$PRG\"`/" >/dev/null
+APP_HOME="`pwd -P`"
+cd "$SAVED" >/dev/null
+
+CLASSPATH=$APP_HOME/gradle/wrapper/gradle-wrapper.jar
+
+# Determine the Java command to use to start the JVM.
+if [ -n "$JAVA_HOME" ] ; then
+ if [ -x "$JAVA_HOME/jre/sh/java" ] ; then
+ # IBM's JDK on AIX uses strange locations for the executables
+ JAVACMD="$JAVA_HOME/jre/sh/java"
+ else
+ JAVACMD="$JAVA_HOME/bin/java"
+ fi
+ if [ ! -x "$JAVACMD" ] ; then
+ die "ERROR: JAVA_HOME is set to an invalid directory: $JAVA_HOME
+
+Please set the JAVA_HOME variable in your environment to match the
+location of your Java installation."
+ fi
+else
+ JAVACMD="java"
+ which java >/dev/null 2>&1 || die "ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
+
+Please set the JAVA_HOME variable in your environment to match the
+location of your Java installation."
+fi
+
+# Increase the maximum file descriptors if we can.
+if [ "$cygwin" = "false" -a "$darwin" = "false" ] ; then
+ MAX_FD_LIMIT=`ulimit -H -n`
+ if [ $? -eq 0 ] ; then
+ if [ "$MAX_FD" = "maximum" -o "$MAX_FD" = "max" ] ; then
+ MAX_FD="$MAX_FD_LIMIT"
+ fi
+ ulimit -n $MAX_FD
+ if [ $? -ne 0 ] ; then
+ warn "Could not set maximum file descriptor limit: $MAX_FD"
+ fi
+ else
+ warn "Could not query maximum file descriptor limit: $MAX_FD_LIMIT"
+ fi
+fi
+
+# For Darwin, add options to specify how the application appears in the dock
+if $darwin; then
+ GRADLE_OPTS="$GRADLE_OPTS \"-Xdock:name=$APP_NAME\" \"-Xdock:icon=$APP_HOME/media/gradle.icns\""
+fi
+
+# For Cygwin, switch paths to Windows format before running java
+if $cygwin ; then
+ APP_HOME=`cygpath --path --mixed "$APP_HOME"`
+ CLASSPATH=`cygpath --path --mixed "$CLASSPATH"`
+ JAVACMD=`cygpath --unix "$JAVACMD"`
+
+ # We build the pattern for arguments to be converted via cygpath
+ ROOTDIRSRAW=`find -L / -maxdepth 1 -mindepth 1 -type d 2>/dev/null`
+ SEP=""
+ for dir in $ROOTDIRSRAW ; do
+ ROOTDIRS="$ROOTDIRS$SEP$dir"
+ SEP="|"
+ done
+ OURCYGPATTERN="(^($ROOTDIRS))"
+ # Add a user-defined pattern to the cygpath arguments
+ if [ "$GRADLE_CYGPATTERN" != "" ] ; then
+ OURCYGPATTERN="$OURCYGPATTERN|($GRADLE_CYGPATTERN)"
+ fi
+ # Now convert the arguments - kludge to limit ourselves to /bin/sh
+ i=0
+ for arg in "$@" ; do
+ CHECK=`echo "$arg"|egrep -c "$OURCYGPATTERN" -`
+ CHECK2=`echo "$arg"|egrep -c "^-"` ### Determine if an option
+
+ if [ $CHECK -ne 0 ] && [ $CHECK2 -eq 0 ] ; then ### Added a condition
+ eval `echo args$i`=`cygpath --path --ignore --mixed "$arg"`
+ else
+ eval `echo args$i`="\"$arg\""
+ fi
+ i=$((i+1))
+ done
+ case $i in
+ (0) set -- ;;
+ (1) set -- "$args0" ;;
+ (2) set -- "$args0" "$args1" ;;
+ (3) set -- "$args0" "$args1" "$args2" ;;
+ (4) set -- "$args0" "$args1" "$args2" "$args3" ;;
+ (5) set -- "$args0" "$args1" "$args2" "$args3" "$args4" ;;
+ (6) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" ;;
+ (7) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" ;;
+ (8) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" "$args7" ;;
+ (9) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" "$args7" "$args8" ;;
+ esac
+fi
+
+# Split up the JVM_OPTS And GRADLE_OPTS values into an array, following the shell quoting and substitution rules
+function splitJvmOpts() {
+ JVM_OPTS=("$@")
+}
+eval splitJvmOpts $DEFAULT_JVM_OPTS $JAVA_OPTS $GRADLE_OPTS
+JVM_OPTS[${#JVM_OPTS[*]}]="-Dorg.gradle.appname=$APP_BASE_NAME"
+
+exec "$JAVACMD" "${JVM_OPTS[@]}" -classpath "$CLASSPATH" org.gradle.wrapper.GradleWrapperMain "$@"
diff --git a/wlauto/workloads/googleslides/uiauto/gradlew.bat b/wlauto/workloads/googleslides/uiauto/gradlew.bat
new file mode 100644
index 00000000..aec99730
--- /dev/null
+++ b/wlauto/workloads/googleslides/uiauto/gradlew.bat
@@ -0,0 +1,90 @@
+@if "%DEBUG%" == "" @echo off
+@rem ##########################################################################
+@rem
+@rem Gradle startup script for Windows
+@rem
+@rem ##########################################################################
+
+@rem Set local scope for the variables with windows NT shell
+if "%OS%"=="Windows_NT" setlocal
+
+@rem Add default JVM options here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM options to this script.
+set DEFAULT_JVM_OPTS=
+
+set DIRNAME=%~dp0
+if "%DIRNAME%" == "" set DIRNAME=.
+set APP_BASE_NAME=%~n0
+set APP_HOME=%DIRNAME%
+
+@rem Find java.exe
+if defined JAVA_HOME goto findJavaFromJavaHome
+
+set JAVA_EXE=java.exe
+%JAVA_EXE% -version >NUL 2>&1
+if "%ERRORLEVEL%" == "0" goto init
+
+echo.
+echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
+echo.
+echo Please set the JAVA_HOME variable in your environment to match the
+echo location of your Java installation.
+
+goto fail
+
+:findJavaFromJavaHome
+set JAVA_HOME=%JAVA_HOME:"=%
+set JAVA_EXE=%JAVA_HOME%/bin/java.exe
+
+if exist "%JAVA_EXE%" goto init
+
+echo.
+echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME%
+echo.
+echo Please set the JAVA_HOME variable in your environment to match the
+echo location of your Java installation.
+
+goto fail
+
+:init
+@rem Get command-line arguments, handling Windowz variants
+
+if not "%OS%" == "Windows_NT" goto win9xME_args
+if "%@eval[2+2]" == "4" goto 4NT_args
+
+:win9xME_args
+@rem Slurp the command line arguments.
+set CMD_LINE_ARGS=
+set _SKIP=2
+
+:win9xME_args_slurp
+if "x%~1" == "x" goto execute
+
+set CMD_LINE_ARGS=%*
+goto execute
+
+:4NT_args
+@rem Get arguments from the 4NT Shell from JP Software
+set CMD_LINE_ARGS=%$
+
+:execute
+@rem Setup the command line
+
+set CLASSPATH=%APP_HOME%\gradle\wrapper\gradle-wrapper.jar
+
+@rem Execute Gradle
+"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %GRADLE_OPTS% "-Dorg.gradle.appname=%APP_BASE_NAME%" -classpath "%CLASSPATH%" org.gradle.wrapper.GradleWrapperMain %CMD_LINE_ARGS%
+
+:end
+@rem End local scope for the variables with windows NT shell
+if "%ERRORLEVEL%"=="0" goto mainEnd
+
+:fail
+rem Set variable GRADLE_EXIT_CONSOLE if you need the _script_ return code instead of
+rem the _cmd.exe /c_ return code!
+if not "" == "%GRADLE_EXIT_CONSOLE%" exit 1
+exit /b 1
+
+:mainEnd
+if "%OS%"=="Windows_NT" endlocal
+
+:omega
diff --git a/wlauto/workloads/googleslides/uiauto/project.properties b/wlauto/workloads/googleslides/uiauto/project.properties
deleted file mode 100644
index ce39f2d0..00000000
--- a/wlauto/workloads/googleslides/uiauto/project.properties
+++ /dev/null
@@ -1,14 +0,0 @@
-# This file is automatically generated by Android Tools.
-# Do not modify this file -- YOUR CHANGES WILL BE ERASED!
-#
-# This file must be checked in Version Control Systems.
-#
-# To customize properties used by the Ant build system edit
-# "ant.properties", and override values to adapt the script to your
-# project structure.
-#
-# To enable ProGuard to shrink and obfuscate your code, uncomment this (available properties: sdk.dir, user.home):
-#proguard.config=${sdk.dir}/tools/proguard/proguard-android.txt:proguard-project.txt
-
-# Project target.
-target=android-18
diff --git a/wlauto/workloads/googleslides/uiauto/settings.gradle b/wlauto/workloads/googleslides/uiauto/settings.gradle
new file mode 100644
index 00000000..e7b4def4
--- /dev/null
+++ b/wlauto/workloads/googleslides/uiauto/settings.gradle
@@ -0,0 +1 @@
+include ':app'
diff --git a/wlauto/workloads/googleslides/uiauto/build.sh b/wlauto/workloads/googleslides/uiauto/build.sh
index 58407ee5..c4e7b164 100755
--- a/wlauto/workloads/googleslides/uiauto/build.sh
+++ b/wlauto/workloads/googleslides/uiauto/build.sh
@@ -8,32 +8,33 @@ fi
script_dir=`dirname $script_path`
cd $script_dir
-# Ensure build.xml exists before starting
-if [[ ! -f build.xml ]]; then
- echo 'Ant build.xml file not found! Check that you are in the right directory.'
+# Ensure gradelw exists before starting
+if [[ ! -f gradlew ]]; then
+ echo 'gradlew file not found! Check that you are in the right directory.'
exit 9
fi
# Copy base classes from wlauto dist
-class_dir=bin/classes/com/arm/wlauto/uiauto
-base_classes=`python -c "import os, wlauto; print os.path.join(os.path.dirname(wlauto.__file__), 'common', 'android', '*.class')"`
-mkdir -p $class_dir
-cp $base_classes $class_dir
+libs_dir=app/libs
+base_classes=`python -c "import os, wlauto; print os.path.join(os.path.dirname(wlauto.__file__), 'common', 'android', '*.aar')"`
+mkdir -p $libs_dir
+cp $base_classes $libs_dir
# Build and return appropriate exit code if failed
-ant build
+# ant build
+./gradlew clean :app:assembleDebug
exit_code=$?
if [[ $exit_code -ne 0 ]]; then
- echo "ERROR: 'ant build' exited with code $exit_code"
+ echo "ERROR: 'gradle build' exited with code $exit_code"
exit $exit_code
fi
-# If successful move JAR file to workload folder (remove previous)
-package=com.arm.wlauto.uiauto.googleslides.jar
+# If successful move APK file to workload folder (overwrite previous)
+package=com.arm.wlauto.uiauto.googleslides
rm -f ../$package
-if [[ -f bin/$package ]]; then
- cp bin/$package ..
+if [[ -f app/build/apk/$package.apk ]]; then
+ cp app/build/apk/$package.apk ../$package.uiautoapk
else
- echo 'ERROR: UiAutomator JAR could not be found!'
+ echo 'ERROR: UiAutomator apk could not be found!'
exit 9
fi